@@ -1162,8 +1162,7 @@ do_new (Context *c, PedPartition **part) {
 	                        pos.end.sector,c->dev,NULL,&opts))
 		return 0;
 
-	PedFileSystemType *fs_type = ped_file_system_type_get("ext2");
-	if (!perform_mkpart(c->disk,&pos,type,bsd_disklabel ? fs_type : NULL,part,opts)) {
+	if (!perform_mkpart(c->disk,&pos,type, part,opts)) {
 		if (!*part) {
 			do {
 				temp = ped_disk_next_partition(c->disk,temp);
@@ -1228,6 +1227,7 @@ int do_edit (Context *c, PedPartition **part) {
 	ped_device_end_external_access(c->disk->dev);
 	return 1;
 }
+
 static int
 do_resize (Context *c, PedPartition **part) {
 	static MenuItem part_position[] = {
@@ -1248,40 +1248,41 @@ do_resize (Context *c, PedPartition **part) {
 	const char resize_keys[] = { 'r', 'c', ESC, '\0' };
 	int key;
 	PedConstraint *constraint = NULL;
-	PedFileSystem *fs = NULL;
 	PedSector first,last;
 	PartPos pos;
 	UIOpts opts = UI_WARN_COMMIT | UI_SNAP_TO_START;
-	if (!((*part)->type & PED_PARTITION_EXTENDED)) {
-		if ((*part)->fs_type && (*part)->fs_type->ops->resize) {
-			menu_title(_("What do you want to do?"));
-			key = do_menu(resize_menu, 11, MENU_BUTTON | MENU_TITLE,resize_keys, NULL);
-		}
-		else {
-			key = 0;
-			getbool(_("Can't resize the partition. Alter the size? (For experts only)"),&key);
-			key = (key ? 'c' : ESC);
-		}
-		if (key == ESC)
-			return 0;
-		if (key == 'r') {
-			fs = ped_file_system_open(&(*part)->geom);
-			if (!fs) {
-				warning_waitkey(_("Could not open the filesystem for resizing"));
+
+	if(!warn_fs_support())
+		return 0;
+
+	if (!((*part)->type & PED_PARTITION_EXTENDED)) 
+		{
+			if ((*part)->fs_type) 
+				{
+					menu_title(_("What do you want to do?"));
+					key = do_menu(resize_menu, 11, MENU_BUTTON | MENU_TITLE,resize_keys, NULL);
+				}
+			else 
+				{
+					key = 0;
+					getbool(_("Can't resize the partition. Alter the size? (For experts only)"),&key);
+					key = (key ? 'c' : ESC);
+				}
+			if (key == ESC)
 				return 0;
-			}
-			constraint = ped_file_system_get_resize_constraint(fs);
-			if (!constraint || constraint->min_size == constraint->max_size) {
-				warning_waitkey(_("We can't resize this filesystem type"));
-				ped_file_system_close (fs);
-				if (constraint) ped_constraint_destroy(constraint);
-				return 0;
-			}
-			ped_file_system_close (fs);
-		} else {
-			opts |= UI_NO_FS_RESIZE;
+			if (key == 'r') 
+				{
+					XASSERT(*part, return 0);
+					XASSERT((*part)->disk, return 0);
+					XASSERT((*part)->disk->dev, return 0);
+
+					constraint = ped_device_get_optimal_aligned_constraint((*part)->disk->dev);
+				} 
+			else 
+				{
+					opts |= UI_NO_FS_RESIZE;
+				}
 		}
-	}
 
 	pos.start.sector = (*part)->geom.start;
 	pos.end.sector = (*part)->geom.end;
@@ -1326,6 +1327,7 @@ do_resize (Context *c, PedPartition **part) {
 	return 1;
 }
 
+#if 0
 static int
 do_move (Context *c, PedPartition **part) {
 	/* Combine this with new partition? */
@@ -1418,6 +1420,7 @@ do_mkfs (Context *c, PedPartition **part) {
 	notice_waitkey(N_("The filesystem was created successfully."));
 	return 1;
 }
+#endif
 
 static int
 do_check (Context *c, PedPartition **part) {
@@ -1468,6 +1471,7 @@ do_rescue(Context *c, PedPartition **part) {
 	return 1;
 }
 
+#if 0
 static int
 do_copy(Context *c, PedPartition **part) {
 	if (!perform_cp(c->disk,*part, UI_WARN_COMMIT)) {
@@ -1478,6 +1482,7 @@ do_copy(Context *c, PedPartition **part) {
 	notice_waitkey(N_("Partition copied successfully"));
 	return 1;
 }
+#endif
 
 static int
 do_delete(Context *c, PedPartition **part) {
@@ -2155,11 +2160,6 @@ main_plist(Context *c, PedPartition **part, int key) {
 			//redraw = 1;
 			key = 0;
 			break;
-		case 'f':
-			do_mkfs(c,part);
-			//redraw = 1;
-			key = 0;
-			break;
 		case 'c':
 			do_check(c,part);
 			//redraw = 1;
@@ -2175,11 +2175,6 @@ main_plist(Context *c, PedPartition **part, int key) {
 			//redraw = 1;
 			key = 0;
 			break;
-		case 'y':
-			do_copy(c,part);
-			//redraw = 1;
-			key = 0;
-			break;
 		case 'r':
 			do_resize(c,part);
 			//redraw = 1;
@@ -2190,11 +2185,6 @@ main_plist(Context *c, PedPartition **part, int key) {
 			//redraw = 1;
 			key = 0;
 			break;
-		case 'o':
-			do_move(c,part);
-			//redraw = 1;
-			key = 0;
-			break;
 		case 'x':
 			do_maximize(c,part);
 			//redraw = 1;
