@@ -32,6 +32,7 @@
 # include "config.h"
 #endif
 
+#include "common.h"
 #include "command.h"
 #include "strlist.h"
 #include "ui.h"
@@ -44,6 +45,9 @@ extern int fdisk_partsize_part; /* ?? */
 
 /* not 0 when fdisk should print the partition table? */
 extern int fdisk_list_table;
+extern int init_disk_flags(PedDisk *disk);
+extern void fdisk_print_partition_size(PedDisk *disk);
+extern void fdisk_do_list_devices (PedDisk* disk);
 
 #if HAVE_LOCALE_H
 # include <locale.h>
@@ -56,45 +60,40 @@ extern int fdisk_list_table;
 /* BEGIN readline stuff */
 #if HAVE_LIBREADLINE
 
-/* Termcap need this buffer to initialize terminal database, I think
-   the db is stored into this buffer but I'm not sure. */
-enum { TERMCAP_BUFFER_SIZE = 2048 };
-static char termcap_buffer[TERMCAP_BUFFER_SIZE] = {0};
+/* If the macro "HAVE_LIBREADLINE corresponds to a digit other than zero
+ * the readline is present along with the respective `readline/readline.h'
+ * and `readline/history.h' header file's */
 
-/* Use this flag to know if termcap is propely initialized
-   and ready or should not be used */
-static enum { TERMCAP_OK, TERMCAP_ERROR } termcap_status;
 
 /* termcap library */
-# if HAVE_TERMCAP_H
-#  include <termcap.h>
-# else
-#  if HAVE_LIBTERMCAP
-    extern int tgetnum (char* key);
-#  endif
-# endif /* HAVE_TERMCAP_H */
+#	if HAVE_LIBTERMCAP
+	/* Termcap need this buffer to initialize terminal database, I think
+	 * the db is stored into this buffer but I'm not sure. */
+		enum { TERMCAP_BUFFER_SIZE = 2048 };
+		static char termcap_buffer[TERMCAP_BUFFER_SIZE] = {0};
 
-/* readline/readline.h */
-# if HAVE_READLINE_READLINE_H
-#  include <readline/readline.h>
-# else
-   extern char * readline ();
-   extern void add_history ();
-# endif /* HAVE_READLINE_READLINE_H */
+		/* Use this flag to know if termcap is propely initialized
+			 and ready or should not be used */
+		static enum { TERMCAP_OK, TERMCAP_ERROR } termcap_status;
+#		if HAVE_TERMCAP_H
+#			include <termcap.h>
+# 	else
+    	extern int tgetnum (char* key);
+#  	endif /* HAVE_TERMCAP_H */
+# endif /* HAVE_LIBTERMCAP */
 
-/* history library */
-# if HAVE_READLINE_HISTORY_H
-#  include <readline/history.h>
-# else
-#  define _add_history_unique add_history
-# endif
+# include <readline/readline.h>
+# include <readline/history.h>
   
-
+/* Both `HAVE_RL_COMPLETION_MATCHES' and `completion_matches' are unused */
+#if 0
 # ifndef HAVE_RL_COMPLETION_MATCHES
 #  define rl_completion_matches completion_matches
 # endif
+#endif /* 0 */
 
-# ifndef rl_compentry_func_t
+# if !HAVE_RL_COMPENTRY_FUNC_T
+	/* cast to (void*) */
 #  define rl_compentry_func_t void
 # endif
 
@@ -113,8 +112,8 @@ static StrList*		ex_opt_str [64];
 static StrList*		on_list;
 static StrList*		off_list;
 static StrList*		on_off_list;
-static StrList*		fs_type_list;
-static StrList*		disk_type_list;
+static StrList*		ui_fs_type_list;
+static StrList*		ui_disk_type_list;
 
 /* Declare readline_state */
 static struct {
@@ -124,15 +123,17 @@ static struct {
   sigjmp_buf	 jmp_state;
 } readline_state;
 
-static PedExceptionOption current_exception_opt = 0;
+// unused
+//static PedExceptionOption current_exception_opt = 0;
 
 /* If we don't want the possibilities to appear on the prompt, this
    should be set to 0. TODO: Making this without a global variable
    might be a good idea */
-static prompt_possibilities = 1;
+static int prompt_possibilities = 1;
 
 
-#if HAVE_LIBREADLINE && HAVE_LIBTERMCAP
+#if HAVE_LIBREADLINE
+#	if HAVE_LIBTERMCAP
 /* This function initialize the termcap library */
 void init_termcap_library(void)
 {
@@ -169,6 +170,7 @@ void init_termcap_library(void)
  _Error:
   termcap_status = TERMCAP_ERROR;
 }
+#endif /* HAVE_LIBTERMCAP */
 
 /* returns matching commands for text */
 static char*
@@ -412,7 +414,7 @@ _construct_prompt (const char* head, const char* def,
   char*	prompt = strdup (head);
 
   if (def && possibilities)
-    PED_ASSERT (str_list_match_any (possibilities, def), return NULL);
+    XASSERT (str_list_match_any (possibilities, def), return NULL);
 
   if (possibilities &&
       prompt_possibilities &&
@@ -464,6 +466,9 @@ _construct_prompt (const char* head, const char* def,
   return prompt;
 }
 
+/* use same function from common.c */
+#if 0
+
 static int
 _can_create_primary (const PedDisk* disk)
 {
@@ -477,6 +482,7 @@ _can_create_primary (const PedDisk* disk)
   return 0;
 }
 
+
 static int
 _can_create_extended (const PedDisk* disk)
 {
@@ -489,6 +495,7 @@ _can_create_extended (const PedDisk* disk)
   return 1;
 }
 
+
 static int
 _can_create_logical (const PedDisk* disk)
 {
@@ -497,6 +504,8 @@ _can_create_logical (const PedDisk* disk)
   return ped_disk_extended_partition (disk) != 0;
 }
 
+#endif
+
 static int
 init_ex_opt_str ()
 {
@@ -544,34 +553,35 @@ done_state_str ()
 }
 
 static int
-init_fs_type_str ()
+ui_init_fs_type_str ()
 {
   PedFileSystemType* walk;
 
-  fs_type_list = NULL;
+  ui_fs_type_list = NULL;
 
   for (walk = ped_file_system_type_get_next (NULL); walk;
        walk = ped_file_system_type_get_next (walk))
     {
-      fs_type_list = str_list_insert (fs_type_list, walk->name);
-      if (!fs_type_list)
+      ui_fs_type_list = str_list_insert (ui_fs_type_list, walk->name);
+      if (!ui_fs_type_list)
 	return 0;
     }
   return 1;
 }
 
 static int
-init_disk_type_str ()
+ui_init_disk_type_str ()
 {
   PedDiskType* walk;
 
-  disk_type_list = NULL;
+  ui_disk_type_list = NULL;
+
 
   for (walk = ped_disk_type_get_next (NULL); walk;
        walk = ped_disk_type_get_next (walk))
     {
-      disk_type_list = str_list_insert (disk_type_list, walk->name);
-      if (!disk_type_list)
+      ui_disk_type_list = str_list_insert (ui_disk_type_list, walk->name);
+      if (!ui_disk_type_list)
 	return 0;
     }
   return 1;
@@ -631,9 +641,7 @@ fdisk_interactive_mode (PedDisk** disk, FdiskCommand* cmd_list[])
 int
 fdisk_interactive_mode(PedDevice **dev, FdiskCommand* cmd_list[])
 {
-  char*	line;
   PedDisk *disk;
-  StrList* list;
   StrList* command_names = fdisk_command_get_names (cmd_list);
     
   puts (interface_name);
@@ -656,6 +664,10 @@ fdisk_interactive_mode(PedDevice **dev, FdiskCommand* cmd_list[])
 		  "content won't be recoverable.\n"));
 	  if((disk = ped_disk_new_fresh(*dev, ped_disk_type_get("msdos"))) == NULL)
 	    return EXIT_FAILURE;
+	  if(!init_disk_flags(disk)) {
+	  	ped_disk_destroy(disk);
+		return EXIT_FAILURE;
+	  }
 	}
       else
 	{
@@ -666,7 +678,8 @@ fdisk_interactive_mode(PedDevice **dev, FdiskCommand* cmd_list[])
 	  char *str;
 
 	  for(label_type = ped_disk_type_get_next(NULL);
-	      label_type = ped_disk_type_get_next(label_type); )
+	      label_type != NULL;
+				label_type = ped_disk_type_get_next(label_type) )
 	    {
 	      supp = str_list_append(supp, label_type->name);
 	      supp = str_list_append(supp, " ");
@@ -709,6 +722,11 @@ fdisk_interactive_mode(PedDevice **dev, FdiskCommand* cmd_list[])
 	  if(!disk)
 	    return EXIT_FAILURE; /* what bad? :( */
 
+	  if (!init_disk_flags(disk)) {
+	  	ped_disk_destroy(disk);
+	  	return EXIT_FAILURE;
+	  }
+	  
 	  /* Free other resources */
 	  free(str);
 	  free(supported_types);
@@ -720,6 +738,10 @@ fdisk_interactive_mode(PedDevice **dev, FdiskCommand* cmd_list[])
       disk = ped_disk_new(*dev);
       if(!disk)
 	return EXIT_FAILURE;
+      if(!init_disk_flags(disk)) {
+	ped_disk_destroy(disk);
+        return EXIT_FAILURE;
+      }
     }
   
   /***
@@ -784,8 +806,6 @@ fdisk_interactive_mode(PedDevice **dev, FdiskCommand* cmd_list[])
 int
 fdisk_interactive_menu (PedDisk** disk, FdiskCommand* cmd_list[], int menu)
 {
-	char*		line;
-	StrList*	list;
 	StrList*	command_names = fdisk_command_get_names (cmd_list);
 
 	/* FIXME yucky, nasty, evil hack */
@@ -860,7 +880,7 @@ fdisk_screen_width ()
     return 32768;	/* no wrapping ;) */
 
 /* HACK: don't specify termcap separately - it'll annoy the users. */
-#if HAVE_LIBREADLINE
+#if HAVE_LIBREADLINE && HAVE_LIBTERMCAP
   if(termcap_status == TERMCAP_OK)
     width = tgetnum ("co");
 #endif
@@ -1063,7 +1083,7 @@ fdisk_command_line_pop_word ()
 	char*		result;
 	StrList*	next;
 
-	PED_ASSERT (command_line != NULL, return NULL);
+	XASSERT (command_line != NULL, return NULL);
 
 	result = str_list_convert_node (command_line);
 	next = command_line->next;
@@ -1165,7 +1185,7 @@ fdisk_command_line_get_disk_type (const char* prompt, const PedDiskType*(* value
 	}
 	*value = ped_disk_type_get (disk_type_name);
 	free (disk_type_name);
-	PED_ASSERT (*value != NULL, return 0);
+	XASSERT (*value != NULL, return 0);
 	return 1;
 }
 #endif
@@ -1207,7 +1227,7 @@ fdisk_command_line_get_integer (const char* prompt, int* value)
 	return valid;
 }
 
-fdisk_command_line_get_llinteger (const char* prompt, long long* value)
+int fdisk_command_line_get_llinteger (const char* prompt, long long* value)
 {
 	char	def_str [22];
 	char*	input;
@@ -1447,14 +1467,14 @@ fdisk_init_ui ()
   
   if (!init_ex_opt_str ()
       || !init_state_str ()
-      || !init_fs_type_str ()
-      || !init_disk_type_str ())
+      || !ui_init_fs_type_str ()
+      || !ui_init_disk_type_str ())
     return 0;
   ped_exception_set_handler (exception_handler);
 
 #if HAVE_LIBREADLINE
   rl_initialize ();
-  rl_attempted_completion_function = (CPPFunction*) fdisk_complete_function;
+	rl_attempted_completion_function = (CPPFunction*) fdisk_complete_function;
 #endif /* HAVE_LIBREADLINE */
 
   readline_state.in_readline = 0; 
@@ -1469,8 +1489,8 @@ fdisk_done_ui ()
   ped_exception_set_handler (NULL);
   done_ex_opt_str ();
   done_state_str ();
-  str_list_destroy (fs_type_list);
-  str_list_destroy (disk_type_list);
+  str_list_destroy (ui_fs_type_list);
+  str_list_destroy (ui_disk_type_list);
 }
 
 int
